Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(160)

Unified Diff: tools/spawn_vm_and_attach.sh

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/servicec/lib/src/resources/java/fletch/Segment.java ('k') | tools/stm/one-stm-lib.ar » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/spawn_vm_and_attach.sh
diff --git a/tools/spawn_vm_and_attach.sh b/tools/spawn_vm_and_attach.sh
index 59e065f3e064441ef82d0a49ba8df04593df8a06..a3496717fd03a38cd63cb0df4de2139c55f74915 100755
--- a/tools/spawn_vm_and_attach.sh
+++ b/tools/spawn_vm_and_attach.sh
@@ -3,22 +3,22 @@
# for details. All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE.md file.
# This program runs the Fletch VM in a virtual terminal controlled by the
# program "screen". It then attaches to the VM using the given command-line
# arguments. Normal usage would be something like:
#
-# ./tools/spawn_vm_and_attach.sh out/DebugIA32Clang/fletch in session SESSION_NAME
+# ./tools/spawn_vm_and_attach.sh out/DebugIA32Clang/dartino in session SESSION_NAME
#
# This is a tool that's intended for people building the Fletch VM. If you find
# yourself using this to run Fletch on a regular basis, please get in touch
# with the authors and let us know why. If you're unsure about how to reach the
# authors, you're welcome to file an issue at
-# https://github.com/dart-lang/fletch/issues/new.
+# https://github.com/dart-lang/dartino/issues/new.
-fletch="${1}"
+dartino="${1}"
shift
-if [ ! -x "${fletch}" ]; then
- echo 1>&2 Usage: "$0" PATH_TO_FLETCH_EXECUTABLE
+if [ ! -x "${dartino}" ]; then
+ echo 1>&2 Usage: "$0" PATH_TO_DARTINO_EXECUTABLE
exit 1
fi
@@ -29,9 +29,9 @@ set -e
fifo=$(mktemp -u -t fifo)
mkfifo "${fifo}"
# Launch the Fletch VM in a detached screen session, and duplicate its output
# to the FIFO (using script)
-screen -L -d -m script -t 0 -q -a "${fifo}" "${fletch}-vm"
+screen -L -d -m script -t 0 -q -a "${fifo}" "${dartino}-vm"
# Wait for the first line of output from the VM
tcp_socket=$(head -1 "${fifo}" | sed 's/^Waiting for compiler on //')
@@ -40,4 +40,4 @@ tcp_socket=$(head -1 "${fifo}" | sed 's/^Waiting for compiler on //')
rm "${fifo}"
# Attach to the VM
-exec "${fletch}" attach tcp_socket "${tcp_socket}" "$@"
+exec "${dartino}" attach tcp_socket "${tcp_socket}" "$@"
« no previous file with comments | « tools/servicec/lib/src/resources/java/fletch/Segment.java ('k') | tools/stm/one-stm-lib.ar » ('j') | no next file with comments »

Powered by Google App Engine
@@ -3,22 +3,22 @@
# for details. All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE.md file.
-# This program runs the Fletch VM in a virtual terminal controlled by the
+# This program runs the Dartino VM in a virtual terminal controlled by the
# program "screen". It then attaches to the VM using the given command-line
# arguments. Normal usage would be something like:
@@ -3,22 +3,22 @@
#
-# This is a tool that's intended for people building the Fletch VM. If you find
-# yourself using this to run Fletch on a regular basis, please get in touch
+# This is a tool that's intended for people building the Dartino VM. If you find
+# yourself using this to run Dartino on a regular basis, please get in touch
# with the authors and let us know why. If you're unsure about how to reach the
# authors, you're welcome to file an issue at
@@ -29,9 +29,9 @@ set -e
fifo=$(mktemp -u -t fifo)
mkfifo "${fifo}"
-# Launch the Fletch VM in a detached screen session, and duplicate its output
+# Launch the Dartino VM in a detached screen session, and duplicate its output
# to the FIFO (using script)
This is Rietveld 408576698